==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/hr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna ploča",
    "Dashboard app" : "Nadzorna ploča aplikacije",
    "Show something" : "Prikaži nešto",
    "Customize" : "Uredi",
    "Edit widgets" : "Uredi widgete",
    "Get more widgets from the app store" : "Pronađite više widgeta u trgovini aplikacijama",
    "Change background image" : "Promijenite sliku pozadinu",
    "Weather service" : "Davatelj vremenske prognoze",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Radi zaštite vaše privatnosti, podatke o vremenskoj prognozi zahtijeva vaš Nextcloud poslužitelj u vaše ime kako davatelj vremenske prognoze ne bi primio vaše osobne podatke.",
    "Weather data from Met.no" : "Podaci o vremenskoj prognozi iz Met.no",
    "geocoding with Nominatim" : "geokodiranje uz Nominatim",
    "elevation data from OpenTopoData" : "podaci o nadmorskoj visini iz OpenTopoData",
    "Weather" : "Vrijeme",
    "Status" : "Status",
    "Good evening, {name}" : "Dobar dan, {name}",
    "Good evening" : "Dobar dan",
    "Good afternoon, {name}" : "Dobar dan, {name}",
    "Good afternoon" : "Dobar dan",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good morning" : "Dobro jutro",
    "Good night, {name}" : "Dobro večer, {name}",
    "Good night" : "Dobro večer",
    "Pick from files" : "Odaberi iz datoteka",
    "Default images" : "Zadane slike",
    "Plain background" : "Obična pozadina",
    "Insert from {productName}" : "Umetni iz {productName}"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/hr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna ploča",
    "Dashboard app" : "Nadzorna ploča aplikacije",
    "Show something" : "Prikaži nešto",
    "Customize" : "Uredi",
    "Edit widgets" : "Uredi widgete",
    "Get more widgets from the app store" : "Pronađite više widgeta u trgovini aplikacijama",
    "Change background image" : "Promijenite sliku pozadinu",
    "Weather service" : "Davatelj vremenske prognoze",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Radi zaštite vaše privatnosti, podatke o vremenskoj prognozi zahtijeva vaš Nextcloud poslužitelj u vaše ime kako davatelj vremenske prognoze ne bi primio vaše osobne podatke.",
    "Weather data from Met.no" : "Podaci o vremenskoj prognozi iz Met.no",
    "geocoding with Nominatim" : "geokodiranje uz Nominatim",
    "elevation data from OpenTopoData" : "podaci o nadmorskoj visini iz OpenTopoData",
    "Weather" : "Vrijeme",
    "Status" : "Status",
    "Good morning" : "Dobro jutro",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good afternoon" : "Dobar dan",
    "Good afternoon, {name}" : "Dobar dan, {name}",
    "Good evening" : "Dobar dan",
    "Good evening, {name}" : "Dobar dan, {name}",
    "Default images" : "Zadane slike",
    "Plain background" : "Obična pozadina",
    "Insert from {productName}" : "Umetni iz {productName}",
    "Good night, {name}" : "Dobro večer, {name}",
    "Good night" : "Dobro večer",
    "Pick from files" : "Odaberi iz datoteka"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
